@@ -1,5 +1,5 @@
 package TreePath;
-$TreePath::VERSION = '0.20';
+$TreePath::VERSION = '0.21';
 use utf8;
 use Moose;
 with 'MooseX::Object::Pluggable';
@@ -389,7 +389,7 @@ sub _normalize_node {
 
   # check parent key
   my $primary_key =  $self->_get_key_name('primary', $node);
-  die "key $primary_key is not set in node !"
+  die "primary key $primary_key is not set in node " . $self->_obj_key($node) ." !\nAdd 'id' to config args/" . $node->{$self->_get_key_name('source',$node) } . "/columns"
       if ! defined $node->{$primary_key};
 
   my $parent_key = $self->_get_key_name('parent', $node);
@@ -551,15 +551,19 @@ This module is at EXPERIMENTAL stage, so use with caution.
  # a node can have children
  my $children = $root->{children};
 
- # or children from another source
+ # or children from another source (if Source has a parent key)
  my $children = $root->{children_Comment};
 
+ # also can has_many relationship. it's the same but without parent key
+ my files = $root->{files};
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new($method => $value)
 
  # for now there are two backends : DBIX and File
  $tp = TreePath->new( conf => 't/conf/treefromdbix.yml')
+ # $tp = TreePath->new( conf => 't/conf/treefromfile.yml')
 
  # see t/conf/treepath.yml for hash structure
  $tp = TreePath->new( datas => $datas);
@@ -605,40 +609,67 @@ This module is at EXPERIMENTAL stage, so use with caution.
 
   where 'Page' is the source of relationship and '10' the id. So Comment_15 is linked with Page_10.
 
-  See the dump :
+  See the dump of a node example :
 
-    {
-      'children' => [
-                      {
-                        'children' => 'ARRAY(0x293ce00)',
-                        'id' => '3',
-                        'name' => 'B',
-                        'parent' => $VAR1
-                        'source' => 'Page'
-                     },
-                      {
-                        'children' => 'ARRAY(0x2fd69b0)',
-                        'id' => '7',
-                        'name' => 'F',
-                        'parent' => $VAR1
-                        'source' => 'Page'
-                      }
-                    ],
-      'id' => '2',
-      'name' => 'A',
-      'parent' => {
-                    'children' => [
-                                    $VAR1
+
+          {
+            'id' => 2,
+            'name' => 'A',
+            'source' => 'Page'
+            'parent' => {
+                          'children' => [
+                                          $VAR1
+                                        ],
+                          'children_Comment' => [
+                                                  'HASH(0x52b6df8)',
+                                                  'HASH(0x52aab28)',
+                                                  'HASH(0x527daf8)'
+                                                ],
+                          'files' => [
+                                       'HASH(0x43de208)',
+                                       'HASH(0x52d8c80)'
+                                     ],
+                          'id' => 1,
+                          'name' => '/',
+                          'parent' => undef,
+                          'source' => 'Page'
+                        },
+            'children' => [
+                            {
+                              'children' => 'ARRAY(0x52cbd70)',
+                              'files' => 'ARRAY(0x52dbc30)',
+                              'id' => 3,
+                              'name' => 'B',
+                              'parent' => $VAR1,
+                              'source' => 'Page'
+                            },
+                            {
+                              'children' => 'ARRAY(0x52dbb58)',
+                              'children_Comment' => 'ARRAY(0x528ba38)',
+                              'files' => 'ARRAY(0x52e45d8)',
+                              'id' => 7,
+                              'name' => "\x{2665}",
+                              'parent' => $VAR1,
+                              'source' => 'Page'
+                            }
+                          ],
+            'children_Comment' => [
+                                    {
+                                      'id' => 3,
+                                      'page' => $VAR1,
+                                      'source' => 'Comment'
+                                    },
+                                    {
+                                      'id' => 4,
+                                      'page' => $VAR1,
+                                      'source' => 'Comment'
+                                    }
                                   ],
-                    'id' => '1',
-                    'name' => '/',
-                    'parent' => '0',
-                    'source' => 'Page'
-                  }
-     'source' => 'Page'
-    }
+            'files' => [],
+          }
 
-    => 'parent' is a reference to root node and 'children' is an array containing 2 nodes
+
+    => 'parent' is a reference to root node and 'children' is an array containing 2 Pages, children_Comment has 2 Comments
 
 =cut
 
