@@ -34,7 +34,7 @@ __PACKAGE__->set_primary_key("id");
 __PACKAGE__->belongs_to(
     "page",
     "Schema::TPath::Result::Page",
-    { id => "page_id" }
+    { "foreign.id" => "self.page_id" }
 );
 
 =head1 NAME
